From 9b89ccfd21e1f5b703f455ce8ac00a55d4d47600 Mon Sep 17 00:00:00 2001
From: Jared Hall <halljared1@gmail.com>
Date: Mon, 28 Mar 2016 14:38:33 -0400
Subject: [PATCH] [SOI] Implemented Neglected Heirloom

---
 .../shadowsoverinnistrad/AshmouthBlade.java   |  15 ++-
 .../NeglectedHeirloom.java                    | 116 ++++++++++++++++++
 2 files changed, 129 insertions(+), 2 deletions(-)
 create mode 100644 Mage.Sets/src/mage/sets/shadowsoverinnistrad/NeglectedHeirloom.java

diff --git a/Mage.Sets/src/mage/sets/shadowsoverinnistrad/NeglectedHeirloom.java b/Mage.Sets/src/mage/sets/shadowsoverinnistrad/NeglectedHeirloom.java
new file mode 100644
index 0000000000..ce24fbb9dd
--- /dev/null
+++ b/Mage.Sets/src/mage/sets/shadowsoverinnistrad/NeglectedHeirloom.java
@@ -0,0 +1,116 @@
+/*
+ *  Copyright 2010 BetaSteward_at_googlemail.com. All rights reserved.
+ *
+ *  Redistribution and use in source and binary forms, with or without modification, are
+ *  permitted provided that the following conditions are met:
+ *
+ *     1. Redistributions of source code must retain the above copyright notice, this list of
+ *        conditions and the following disclaimer.
+ *
+ *     2. Redistributions in binary form must reproduce the above copyright notice, this list
+ *        of conditions and the following disclaimer in the documentation and/or other materials
+ *        provided with the distribution.
+ *
+ *  THIS SOFTWARE IS PROVIDED BY BetaSteward_at_googlemail.com ``AS IS'' AND ANY EXPRESS OR IMPLIED
+ *  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
+ *  FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL BetaSteward_at_googlemail.com OR
+ *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ *  CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+ *  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
+ *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
+ *  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ *  The views and conclusions contained in the software and documentation are those of the
+ *  authors and should not be interpreted as representing official policies, either expressed
+ *  or implied, of BetaSteward_at_googlemail.com.
+ */
+package mage.sets.shadowsoverinnistrad;
+
+import java.util.UUID;
+import mage.abilities.TriggeredAbilityImpl;
+import mage.abilities.common.SimpleStaticAbility;
+import mage.abilities.costs.mana.GenericManaCost;
+import mage.abilities.effects.common.TransformSourceEffect;
+import mage.abilities.effects.common.continuous.BoostEquippedEffect;
+import mage.abilities.keyword.EquipAbility;
+import mage.abilities.keyword.TransformAbility;
+import mage.cards.CardImpl;
+import mage.constants.CardType;
+import mage.constants.Outcome;
+import mage.constants.Rarity;
+import mage.constants.Zone;
+import mage.game.Game;
+import mage.game.events.GameEvent;
+
+/**
+ *
+ * @author halljared
+ */
+public class NeglectedHeirloom extends CardImpl {
+
+    public NeglectedHeirloom(UUID ownerId) {
+        super(ownerId, 260, "Neglected Heirloom", Rarity.UNCOMMON, new CardType[]{CardType.ARTIFACT}, "{1}");
+        this.expansionSetCode = "SOI";
+        this.subtype.add("Equipment");
+
+        this.canTransform = true;
+        this.secondSideCard = new AshmouthBlade(ownerId);
+
+        // Equipped creature gets +1/+1.
+        this.addAbility(new SimpleStaticAbility(Zone.BATTLEFIELD, new BoostEquippedEffect(1, 1)));
+        // Equip {1}
+        this.addAbility(new EquipAbility(Outcome.AddAbility, new GenericManaCost(1)));
+
+        // When equipped creature transforms, transform Neglected Heirloom.
+        this.addAbility(new TransformAbility());
+        this.addAbility(new NeglectedHeirloomTriggeredAbility());
+
+    }
+
+    public NeglectedHeirloom(final NeglectedHeirloom card) {
+        super(card);
+    }
+
+    @Override
+    public NeglectedHeirloom copy() {
+        return new NeglectedHeirloom(this);
+    }
+
+}
+
+class NeglectedHeirloomTriggeredAbility extends TriggeredAbilityImpl {
+
+    public NeglectedHeirloomTriggeredAbility() {
+        super(Zone.BATTLEFIELD, new TransformSourceEffect(true), false);
+    }
+
+    public NeglectedHeirloomTriggeredAbility(final NeglectedHeirloomTriggeredAbility ability) {
+        super(ability);
+    }
+
+    @Override
+    public boolean checkEventType(GameEvent event, Game game) {
+        return event.getType() == GameEvent.EventType.TRANSFORMED;
+    }
+
+    @Override
+    public boolean checkTrigger(GameEvent event, Game game) {
+        if (event.getType() == GameEvent.EventType.TRANSFORMED) {
+            if (game.getPermanent(event.getTargetId()).getAttachments().contains(this.getSourceId())) {
+                return true;
+            }
+        }
+        return false;
+    }
+
+    @Override
+    public NeglectedHeirloomTriggeredAbility copy() {
+        return new NeglectedHeirloomTriggeredAbility(this);
+    }
+
+    @Override
+    public String getRule() {
+        return "When equipped creature transforms, transform Neglected Heirloom.";
+    }
+}
\ No newline at end of file
diff --git a/Mage.Sets/src/mage/sets/shadowsoverinnistrad/AshmouthBlade.java b/Mage.Sets/src/mage/sets/shadowsoverinnistrad/AshmouthBlade.java
index c87dff1819..a4c27292a9 100644
--- a/Mage.Sets/src/mage/sets/shadowsoverinnistrad/AshmouthBlade.java
+++ b/Mage.Sets/src/mage/sets/shadowsoverinnistrad/AshmouthBlade.java
@@ -28,11 +28,16 @@
 package mage.sets.shadowsoverinnistrad;
 
 import java.util.UUID;
+import mage.abilities.Ability;
 import mage.abilities.common.SimpleStaticAbility;
 import mage.abilities.costs.mana.GenericManaCost;
+import mage.abilities.effects.Effect;
 import mage.abilities.effects.common.continuous.BoostEquippedEffect;
+import mage.abilities.effects.common.continuous.GainAbilityAttachedEffect;
 import mage.abilities.keyword.EquipAbility;
+import mage.abilities.keyword.FirstStrikeAbility;
 import mage.cards.CardImpl;
+import mage.constants.AttachmentType;
 import mage.constants.CardType;
 import mage.constants.Outcome;
 import mage.constants.Rarity;
@@ -52,8 +57,14 @@ public class AshmouthBlade extends CardImpl {
         // this card is the second face of double-faced card
         this.nightCard = true;
 
-        // Equipped creature gets +3/+3.
-        this.addAbility(new SimpleStaticAbility(Zone.BATTLEFIELD, new BoostEquippedEffect(3, 3)));
+        // Equipped creature gets +3/+3
+        Ability ability = new SimpleStaticAbility(Zone.BATTLEFIELD, new BoostEquippedEffect(3, 3));
+        this.addAbility(ability);
+
+        // and has first strike.
+        Effect effect = new GainAbilityAttachedEffect(FirstStrikeAbility.getInstance(), AttachmentType.EQUIPMENT);
+        effect.setText("and has first strike");
+        ability.addEffect(effect);
 
         // Equip {3}
         this.addAbility(new EquipAbility(Outcome.AddAbility, new GenericManaCost(3)));